Package: TDbasedUFEadv
Type: Package
Title: Advanced package of tensor decomposition based unsupervised
        feature extraction
Version: 1.12.1
Language: en-US
Authors@R: 
    person("Y-h.", "Taguchi", ,
    "tag@granular.com", role = c("aut", "cre"),
    comment = c(ORCID  = "0000-0003-0867-8986"))
Description: 
    This is an advanced version of TDbasedUFE, which is a  comprehensive package
    to perform Tensor decomposition based unsupervised feature extraction.
    In contrast to TDbasedUFE which can perform simple the feature selection and 
    the multiomics analyses, this package can perform more complicated and 
    advanced features, but they are not so popularly required. Only users who 
    require more specific features can make use of its functionality. 
biocViews: GeneExpression, FeatureExtraction, MethylationArray,
        SingleCell, Software
License: GPL-3
Encoding: UTF-8
Imports: TDbasedUFE, Biobase, GenomicRanges, utils, rTensor, methods,
        graphics, stats, hash, shiny
BugReports: https://github.com/tagtag/TDbasedUFEadv/issues
URL: https://github.com/tagtag/TDbasedUFEadv
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), RTCGA.rnaseq,
        RTCGA.clinical, BiocStyle, MOFAdata, STRINGdb, enrichR,
        enrichplot, DOSE, gson, ggplot2
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/TDbasedUFEadv
git_branch: RELEASE_3_23
git_last_commit: 3703f3a
git_last_commit_date: 2026-05-04
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-06 00:45:57 UTC; biocbuild
Author: Y-h. Taguchi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0867-8986>)
Maintainer: Y-h. Taguchi <tag@granular.com>
