# Generated by roxygen2: do not edit by hand

export(computeSVD)
export(prepareCondDrugandDisease)
export(prepareCondTCGA)
export(prepareTensorRect)
export(prepareTensorfromList)
export(prepareTensorfromMatrix)
export(prepareexpDrugandDisease)
export(selectFeatureProj)
export(selectFeatureRect)
export(selectFeatureTransRect)
export(transSVD)
import(Biobase)
import(TDbasedUFE)
importFrom(GenomicRanges,GRanges)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,boxplot)
importFrom(graphics,hist)
importFrom(graphics,par)
importFrom(hash,keys)
importFrom(methods,is)
importFrom(methods,new)
importFrom(rTensor,as.tensor)
importFrom(rTensor,hosvd)
importFrom(shiny,actionButton)
importFrom(shiny,fluidPage)
importFrom(shiny,h3)
importFrom(shiny,mainPanel)
importFrom(shiny,observeEvent)
importFrom(shiny,plotOutput)
importFrom(shiny,renderPlot)
importFrom(shiny,runApp)
importFrom(shiny,shinyApp)
importFrom(shiny,sidebarLayout)
importFrom(shiny,sidebarPanel)
importFrom(shiny,stopApp)
importFrom(stats,filter)
importFrom(stats,optim)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,var)
importFrom(utils,read.csv)
