drug_response.txt is included in
http://lifeome.net/supp/drug_response/
First, download 
http://lifeome.net/supp/drug_response/response.zip
and unzip. Then you can get  drug_response.txt.

drug_response.txt is an ascii text file.
It includes fifteen columns, "cancers", "patient.arr", "drug.name", "drug.id",
"response", "start.time", "end.time", "pathological_time", "procurement_method",
"procurement_time", "nte_time", "nte_pharm", "nte_surgery"", separated by tab.
Among them we do need association between "patient.arr" and "drug.name"", 
although  "cancers" are also requied to idenfied files that gene expression 
is stored.