#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom stats var
#' @importFrom methods new is
#' @importFrom utils read.csv
#' @import TDbasedUFE
#' @import Biobase
#' @importFrom shiny fluidPage sidebarLayout  sidebarPanel actionButton mainPanel 
#' @importFrom shiny plotOutput observeEvent runApp shinyApp stopApp renderPlot h3
#' @importFrom GenomicRanges GRanges
#' @importFrom rTensor hosvd as.tensor
#' @importFrom stats pchisq p.adjust optim
#' @importFrom graphics hist par arrows boxplot abline
#' @importFrom hash keys
#' @importFrom stats filter
## usethis namespace: end
NULL
